@@ -3,7 +3,9 @@ package HTML::Latemp::NavLinks::GenHtml;
 use warnings;
 use strict;
 
-use base 'Class::Accessor';
+use 5.008;
+
+use parent 'Class::Accessor';
 
 __PACKAGE__->mk_accessors(qw(
     nav_links_obj
@@ -17,7 +19,7 @@ navigation links.
 
 =cut
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.2.2';
 
 =head1 SYNOPSIS
 
